Krinkle has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/245899

Change subject: objectcache: Rename WANObjectCache TTL_NONE to TTL_INDEF
......................................................................

objectcache: Rename WANObjectCache TTL_NONE to TTL_INDEF

"None" has a somewhat unobvious meaning, also ambiguous with "uncachable".

Change-Id: I799de385427aeb8f581d51800606552bdc998252
---
M includes/cache/MessageCache.php
M includes/libs/objectcache/WANObjectCache.php
2 files changed, 3 insertions(+), 3 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/mediawiki/core 
refs/changes/99/245899/1

diff --git a/includes/cache/MessageCache.php b/includes/cache/MessageCache.php
index ef70589..2b31f86 100644
--- a/includes/cache/MessageCache.php
+++ b/includes/cache/MessageCache.php
@@ -675,7 +675,7 @@
                                'hash' => $cache['HASH'],
                                'latest' => isset( $cache['LATEST'] ) ? 
$cache['LATEST'] : 0
                        ),
-                       WANObjectCache::TTL_NONE
+                       WANObjectCache::TTL_INDEF
                );
        }
 
diff --git a/includes/libs/objectcache/WANObjectCache.php 
b/includes/libs/objectcache/WANObjectCache.php
index b0cb775..8c30a5b 100644
--- a/includes/libs/objectcache/WANObjectCache.php
+++ b/includes/libs/objectcache/WANObjectCache.php
@@ -89,7 +89,7 @@
        const LOCK_TSE = 1;
 
        /** Idiom for set()/getWithSetCallback() TTL being "forever" */
-       const TTL_NONE = 0;
+       const TTL_INDEF = 0;
        /** Idiom for getWithSetCallback() callbacks to avoid calling set() */
        const TTL_UNCACHEABLE = -1;
        /** Idiom for getWithSetCallback() callbacks to 'lockTSE' logic */
@@ -627,7 +627,7 @@
         *
         * @param string $key Cache key
         * @param integer $ttl Seconds to live for key updates. Special values 
are:
         *   - WANObjectCache::TTL_NONE : Cache forever
         *   - WANObjectCache::TTL_UNCACHEABLE: Do not cache at all
         * @param callable $callback Value generation function
         * @param array $opts Options map:
@@ -627,7 +627,7 @@
         * @param integer $ttl Seconds to live for key updates. Special values 
are:
-        *   - WANObjectCache::TTL_NONE : Cache forever
+        *   - WANObjectCache::TTL_INDEF: Cache forever
         *   - WANObjectCache::TTL_UNCACHEABLE: Do not cache at all
         * @param callable $callback Value generation function

-- 
To view, visit https://gerrit.wikimedia.org/r/245899
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I799de385427aeb8f581d51800606552bdc998252
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/core
Gerrit-Branch: master
Gerrit-Owner: Krinkle <[email protected]>

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to